@@ -1193,9 +1193,12 @@ def get_metrics(X,y):
     dct['test.CHISQ.log10'] = np.log10 (p)
     dct['test.CHISQ.CHI2'] = C
 
-    dct_ecol,_ = ECoL_metrics(X,y)
-    dct.update(dct_ecol)
-    
+    try:
+        dct_ecol,_ = ECoL_metrics(X,y)
+        dct.update(dct_ecol)
+    except Exception as e:
+        print(e)
+
     dct_s = {}
     
     for k, v in dct.items():
@@ -1274,10 +1277,12 @@ def get_html(X,y):
     tr = '<tr><td> ES = ' + str(es) + '<br/>' + es_img + '</td><tr>'
     html += tr
     
-    _, ecol = ECoL_metrics(X,y)
-
-    tr = '<tr><td> ECoL metrics' + '<br/><br/><pre>' + ecol + '</pre></td><tr>'
-    html += tr
+    try:
+        _, ecol = ECoL_metrics(X,y)
+        tr = '<tr><td> ECoL metrics' + '<br/><br/><pre>' + ecol + '</pre></td><tr>'
+        html += tr
+    except Exception as e:
+        print(e)
 
     # dataset summary
     tr = '<tr><th> Dataset Summary </th><tr>' 
